Received: from localhost (maia-3.hub.org [200.46.204.184]) by postgresql.org (Postfix) with ESMTP id 0D3B69FA28E for ; Mon, 1 Jan 2007 11:14:22 -0400 (AST) Received: from postgresql.org ([200.46.204.71]) by localhost (mx1.hub.org [200.46.204.184]) (amavisd-new, port 10024) with ESMTP id 19464-08 for ; Mon, 1 Jan 2007 11:14:11 -0400 (AST) X-Greylist: from auto-whitelisted by SQLgrey-1.7.4 Received: from web26310.mail.ukl.yahoo.com (web26310.mail.ukl.yahoo.com [217.146.176.21]) by postgresql.org (Postfix) with SMTP id A2DD19F95E3 for ; Mon, 1 Jan 2007 11:14:16 -0400 (AST) Received: (qmail 18863 invoked by uid 60001); 1 Jan 2007 15:14:14 -0000 DomainKey-Signature: a=rsa-sha1; q=dns; c=nofws; s=s1024; d=yahoo.no; h=X-YMail-OSG:Received:Date:From:Subject:To:Cc:In-Reply-To:MIME-Version:Content-Type:Content-Transfer-Encoding:Message-ID; b=pKIYBEk5Qk3eE7U2xVWNr/IXRhp8dedeant7yrlgpb2eGJh9DMlDKL+m4/yIDPosaJo9spERVSdRozTtDzVvp4qZVbzi9mfd1Z7OVtf0mPASC1o0vKuQBxjub8s6VGG+F7r+F3ZFAboovl8z2Z3iZ+kGqcwPWBEvc3cQDAXCOjw=; X-YMail-OSG: aEnwxgIVM1kd9ZrS4LDVQSJmsSc6dmQ6wyLE9CSaPbbff6OIOxbKJudOKVqFE9RnH4X7bAOJ3Vo1OIGhvBF2fWu6RKH9eB9gOkTaN8LIMziXM8CwSieinKTgY9HqbnYI407X0nT_6klsIVuSGZjZzj7S57n4H_JhxFplcU5JROm30AkJ_GIleHMPvA-- Received: from [81.175.5.65] by web26310.mail.ukl.yahoo.com via HTTP; Mon, 01 Jan 2007 16:14:14 CET Date: Mon, 1 Jan 2007 16:14:14 +0100 (CET) From: =?iso-8859-1?q?Rolf=20=D8stvik?= Subject: Re: Worse perfomance on 8.2.0 than on 7.4.14 To: Dave Cramer Cc: pgsql-performance@postgresql.org In-Reply-To: <5AB35188-5686-4201-A182-5A0321288084@fastcrypt.com> MIME-Version: 1.0 Content-Type: text/plain; charset=iso-8859-1 Content-Transfer-Encoding: 8bit Message-ID: <537403.18171.qm@web26310.mail.ukl.yahoo.com> X-Virus-Scanned: Maia Mailguard 1.0.1 X-Archive-Number: 200701/2 X-Sequence-Number: 22603 --- Dave Cramer skrev: > > On 31-Dec-06, at 6:33 AM, Rolf Østvik wrote: > > > > > Hi > > > > I have a simple query which uses 32ms on 7.4.14 > and 1015ms on 8.2.0. > > I guess 7.4.14 creates a better execution plan > than 8.2.0 for this > > query but > > i don't know how to get it to select a better one. > > Explain analyse output will be found near the end > of the e-mail. > > > > (I have simplified my real query to get it as > simple as possible. > > The original query > > contain 6 tables and was acceptable on 7.4.2, but > took far too long > > on 8.1.4) > > > > I have made a test setup to compare 7.4.14, 8.1.4 > and 8.2.0. > > 8.1.4 and 8.2.0 uses the same execution plan and > same time to execute. > > > > postgresql.conf values i changed is > > 7.4.14 > > Raised shared_buffers from 32MB to 128MB > > Raised temp_buffers from 8MB to 32MB > > 8.2.0 > > Raised shared_buffers from 32MB to 128MB > > Raised temp_buffers from 8MB to 32MB > > Raised work_mem from 1MB to 8MB > > > set effective_cache to 3G > shared buffers should be 1G on this computer for 8.2 Thanks for the input. Did not have a big influence on my specific problem but comments as this is very valuable in the total setup of my server. Best regards Rolf Østvik __________________________________________________ Bruker du Yahoo!? Lei av spam? Yahoo! Mail har den beste spambeskyttelsen http://no.mail.yahoo.com